@@ -9,9 +9,9 @@ use mixed_num::traits::*;
 /// ## Arguments
 /// 
 /// * `x` - The number transform.
-/// 
+///
 pub fn to_polar<T>( x: Complex<T> ) -> Polar<T>
-    where T:  MixedNum + MixedNumSigned
+    where T:  MixedNum + MixedNumSigned + MixedSqrt
 {
     let c_polar = Polar::<T>{
         r:     abs(x),
@@ -26,11 +26,21 @@ pub fn to_polar<T>( x: Complex<T> ) -> Polar<T>
 /// 
 /// * `a` - The argument to apply the function to.
 /// 
+/// ## Example
+/// 
+/// ```
+/// use num::complex::Complex;
+/// use fixed_trigonometry::complex::*;
+/// 
+/// let mut x = Complex{re:1f32, im:0f32};
+/// assert_eq!{ abs(x), 1f32 };
+/// ``` 
+/// 
 pub fn abs<T>( a: Complex<T> ) -> T
-where T: MixedNum + MixedNumSigned
+where T: MixedNum + MixedNumSigned + MixedSqrt
 {
     let r_sqr = super::powi( a.re, 2) + super::powi( a.im, 2);
-    return trigonometry::sqrt::niirf(r_sqr, 2);
+    return r_sqr.mixed_sqrt();
 }
 
 /// Polar complex nuber.
@@ -45,13 +55,21 @@ pub struct Polar<T> {
 /// 
 /// * `a` - The number transform.
 /// 
+/// ## Example
+/// 
+/// ```
+/// use num::complex::Complex;
+/// use fixed_trigonometry::complex::*;
+/// 
+/// let mut x = Polar{r:1f32, theta:0f32};
+/// assert_eq!{ to_cartsian(x).to_string(), "1+0i" };
+/// ``` 
+/// 
 pub fn to_cartsian<T>( a: Polar<T> ) -> Complex<T>
     where T: MixedNum + MixedNumSigned + MixedTrigonometry
 {
     let theta = crate::wrap_phase(a.theta);
-    //let (imag_s, real_s) = cordic::sin_cos( theta );
-    let imag_s = theta.mixed_sin();
-    let real_s = theta.mixed_cos();
+    let (imag_s, real_s) = theta.mixed_sincos();
 
     let c_cartesian = Complex::<T>{
         re: a.r*real_s,
@@ -61,6 +79,7 @@ pub fn to_cartsian<T>( a: Polar<T> ) -> Complex<T>
 }
 
 /// Add two complex fixed-point numbers in cartesian form.
+/// 
 pub fn add<T>( a: Complex<T>, b: Complex<T> ) -> Complex<T>
     where T: MixedNum
 {
@@ -73,6 +92,7 @@ pub fn add<T>( a: Complex<T>, b: Complex<T> ) -> Complex<T>
 
 /// Subtract b from a.
 /// c = a-b
+/// 
 pub fn sub<T>( a: Complex<T>, b: Complex<T> ) -> Complex<T>
     where T: MixedNum + MixedNumSigned
 {
@@ -84,6 +104,7 @@ pub fn sub<T>( a: Complex<T>, b: Complex<T> ) -> Complex<T>
 }
 
 /// Multiply fixed-point complex numbers in polar form.
+/// 
 pub fn mul_polar<T>( a: Polar<T>, b: Polar<T> ) -> Polar<T>
     where T: MixedNum + MixedNumSigned
 {
@@ -105,15 +126,19 @@ pub fn mul_polar<T>( a: Polar<T>, b: Polar<T> ) -> Polar<T>
     }
 }
 
-/// Multiply two polar numbers by transforming to polar, multiplying and transfomring back.
-pub fn mul_cartesian<T>( a: Complex<T>, b: Complex<T> ) -> Complex<T>
-    where T:  MixedNum + MixedNumSigned  + MixedTrigonometry
-{
-    let a_pol = to_polar(a);
-    let b_pol = to_polar(b);
+/// Multiply two cartesian complex numbers.
+/// 
+pub fn mul_cartesian<T>( ab: Complex<T>, bc: Complex<T> ) -> Complex<T>
+    where T:  MixedNum + MixedNumSigned 
+{   
+    let a = ab.re;
+    let b = ab.im;
+    let c = bc.re;
+    let d = bc.im;
 
-    let c_pol = mul_polar(a_pol, b_pol);
-    return to_cartsian(c_pol);
+    let re = (a*c) - (b*d);
+    let im = (a*d) + (b*c);
+    return Complex{re:re, im:im}
 }
 
 /// Rase a complex fixed-point number to an real-valued integer power.
@@ -138,6 +163,7 @@ pub fn mul_cartesian<T>( a: Complex<T>, b: Complex<T> ) -> Complex<T>
 /// let result = Complex::new( FixedI32::<U22>::from_num( -0.019603, ), FixedI32::<U22>::from_num( 1.9959388 ));
 /// assert_eq!{ y, result };
 /// ```
+/// 
 pub fn powi<T>( base: num::complex::Complex<T>, power:usize ) -> num::complex::Complex<T>
     where T: fixed::traits::FixedSigned + cordic::CordicNumber + MixedNum + MixedNumSigned
 {   
@@ -155,8 +181,9 @@ pub fn powi<T>( base: num::complex::Complex<T>, power:usize ) -> num::complex::C
     return num::complex::Complex::new( real, imag);
 }
 
-/// divide a cartesian complex by a real scalar.
+/// Divide a cartesian complex by a real scalar.
 /// c = a/b
+/// 
 pub fn div_cartesian<T>( a: Complex<T>, b: T  ) -> Complex<T>
     where T: MixedNum + MixedNumSigned
 {
